@@ -464,6 +464,16 @@ class GptManager:
         content = eatAll(content,['\n'])
         return content
     
+    def add_to_request(self,content):
+        """
+        adds the user's entered request to the request chunk. It also updates the 'chunk_text_number' in the GUI.
+ 	"""
+        request_data = self.request_data_list[self.get_prompt_data_section_number()]
+        if request_data:
+            content = request_data+'\n\n'+content
+        content = eatAll(content,['\n'])
+        update_request_data(content)
+        return content
     ## chunk data keys
     def chunk_event_check(self):
         """
@@ -483,7 +493,8 @@ class GptManager:
                             '-COMPLETION_PERCENTAGE-',
                             '-PROMPT_PERCENTAGE-'] or self.script_event_js['found'] in ['-FILE_TEXT-',
                                                                                         '-ADD_FILE_TO_CHUNK-',
-                                                                                        '-ADD_URL_TO_CHUNK-']:
+                                                                                       '-ADD_URL_TO_CHUNK-']:
+            request_data=False
             data=None
             if self.event == '-CLEAR_CHUNKS-':
                 """
@@ -517,7 +528,12 @@ class GptManager:
                 self.chunk_title=self.window_mgr.get_values()[text_to_key('-CHUNK_TITLE-',section='files')]
                 data = self.add_to_chunk(self.window_mgr.get_values()[self.script_event_js['-FILE_TEXT-']])
                 self.chunk_type='CODE'
-            self.update_prompt_data(data)
+                
+            elif self.script_event_js['found']=='-ADD_FILE_TO_REQUEST-':
+                self.add_to_request(self.window_mgr.get_values()[self.script_event_js['-FILE_TEXT-']])
+                request_data=True
+            if not request_data:
+                self.update_prompt_data(data)
 
         else:
             return False
@@ -569,9 +585,10 @@ class GptManager:
         key isn't in the GUI's value list, it appends the instruction to the '-other-' section of feedback in the GUI.
  	"""
         for key in self.instruction_pre_keys:
-            value = get_any_value(safe_json_loads(self.last_content),key)
+            value = self.last_response_content.get(key)
+            if isinstance(value,list) and value:
+                value=value[0]
             setattr(self,'last_'+key,value)
-            self.unlist_self(['last_'+key])
             instruction_key = text_to_key(key,section='feedback')
             if instruction_key not in self.window_mgr.get_values():
                 if value:
@@ -810,10 +827,11 @@ class GptManager:
             bool: True if a response event has been triggered, otherwise False
         """
         if self.event == "-COLLATE_RESPONSES_BOOL-":
-            if self.window_mgr.get_values()["-COLLATE_RESPONSES_BOOL-"]:
+            if self.window_mgr.get_values()["-COLLATE_BOOL_RESPONSES-"]:
                 files_list = self.window['-FILES_LIST_RESPONSES-'].Values
+                response_key = self.window_mgr.get_values()['-KEY_SELECTION_RESPONSES-'] or 'api_response'
                 if len(files_list)>0:
-                    collator = FileCollator(files_list)
+                    collator = collate_responses(files_list,response_key)
                     collated_responses=collator.get_gollated_responses(files_list,key_value = 'response')
                     self.window_mgr.update_value('-FILE_TEXT_RESPONSES-',collated_responses)
                     
@@ -851,18 +869,21 @@ class GptManager:
         self.last_file_path= get_any_value(safe_json_loads(self.current_output),'file_path')
         self.last_title= get_any_value(safe_json_loads(self.current_output),'title')
         self.last_model =get_any_value(safe_json_loads(self.current_output),'model')
+        if isinstance(self.last_model,list) and self.last_model:
+            self.last_model = self.last_model[-1]
         self.last_prompt_content,self.last_response_content=get_data_from_response_file(self.last_file_path)
-        self.unlist_self(["last_prompt","last_title","last_file_path","last_prompt"])
+        self.last_prompt = eatAll(self.last_prompt_content.get('prompt'),['',' ','\t','\n'])
+        if not isinstance(self.last_response_content,dict):
+            self.last_response_content={'api_response':self.last_response_content}
         self.last_api_response = self.last_response_content.get('api_response')
-        self.unlist_self(["last_model","last_api_response","last_content"])
         self.window_mgr.update_value(key=text_to_key('title input'),value=self.last_title)
-        response_content = self.last_content
+        response_content = self.last_response_content
         if self.last_api_response:
             response_content=self.last_api_response
             self.delegate_instruction_text()
         self.window_mgr.update_value('-RESPONSE-',self.get_output_response(model=self.last_model,
                                                                            title=self.last_title,
-                                                                           request=self.last_prompt_content.get('prompt'),
+                                                                           request=self.last_prompt,
                                                                            response=response_content))
     def get_current_request_data(self):
         num=0
@@ -1015,7 +1036,16 @@ class GptManager:
                     files_list.remove(file_path)
             files_list=self.new_response_path_list+files_list
             self.window_mgr.update_value('-FILES_LIST_RESPONSES-',args={"values":files_list})
-
+            response_key_list = []
+            for file_path in files_list:
+                data = safe_read_from_json(file_path)
+                response_content = get_response_content(data)
+                if not isinstance(response_content,dict):
+                    response_content = {"api_response":response_content}
+                for key in list(response_content.keys()):
+                    if key not in response_key_list:
+                        response_key_list.append(key)
+            self.window['-KEY_SELECTION_RESPONSES-'].update(values=response_key_list)
     def aggregate_conversations(self,directory:str=None):
         """
         Aggregates conversations from JSON files in the specified directory.
