@@ -93,7 +93,9 @@ class AbstractBrowser:
             sg.Button('<-', key=text_to_key(text='browse backwards',section=section)),
             sg.Button('All Scan Mode', key=text_to_key(text='mode',section=section)),
             sg.Button('->', key=text_to_key(text='browse forwards',section=section)),
+            sg.Button('^', key=text_to_key(text='move up list',section=section)),
             sg.Button('Add', key=text_to_key(text='add_to_list',section=section)),
+            sg.Button('v', key=text_to_key(text='move down list',section=section)),
             sg.Button('Clear', key=text_to_key(text='clear list',section=section))
         ] + extra_buttons
 
@@ -143,6 +145,8 @@ class AbstractBrowser:
                 self.mode_tracker[self.event_key_js['-MODE-']]=self.mode_tracker[self.event_key_js['-MODE-']][1:]
             self.window.Element(self.event_key_js['-MODE-']).update(text=f"{capitalize(self.scan_mode)} Scan Mode")
             self.scan_it(self.return_directory())
+        if self.event_key_js['found'] in ['-MOVE_UP_LIST-','-MOVE_DOWN_LIST-']:
+            
         if self.event_key_js['found'] == '-ADD_TO_LIST-':
             file_list = self.values[self.event_key_js['-BROWSER_LIST-']]
             files_list = self.values[self.event_key_js['-FILES_LIST-']] or []
@@ -179,6 +183,53 @@ class AbstractBrowser:
             except:
                 print(f'could not scan directory {directory}')
         return self.event,self.values
+    def list_it():
+        def get_list_num(list_obj, var):
+            if list_obj:
+                if var == list_obj[-1]:
+                    return len(list_obj)-1
+                if list_obj[0] == var:
+                    return 0
+            for i, obj in enumerate(list_obj):
+                if obj == var:
+                    return i
+
+        def add_position(list_obj, var, num, direction):
+            new_list = []
+            for i, obj in enumerate(list_obj):
+                if i == num:
+                    if direction == 'down':
+                        new_list.append(obj)
+                        new_list.append(var)
+                    else:
+                        new_list.append(var)
+                        new_list.append(obj)
+                else:
+                    new_list.append(obj)
+            return new_list
+        list_values = self.window[self.event_key_js['-FILES_LIST-']].Values
+        list_value = self.values[self.event_key_js['-FILES_LIST-']]
+        if list_value:
+            list_value = list_value[0]
+            position = get_list_num(list_values, list_value)
+            if self.event.split('_')[0].lower() == 'move':
+                direction = self.event.split('_')[1]
+                if direction.lower() == 'up' and position > 0:
+                    list_values.remove(list_value)
+                    position -= 1
+                    list_values = add_position(
+                        list_values, list_value, position, direction)
+                if direction == 'down' and position < len(list_values)-1:
+                    list_values.remove(list_value)
+                    list_values = add_position(
+                        list_values, list_value, position, direction)
+                self.window[self.event_key_js['-FILES_LIST-']].update(values=list_values)
+                self.window[self.event_key_js['-FILES_LIST-']].update(
+                    set_to_index=[get_list_num(list_values, list_value)])
+            elif event == 'remove':
+                list_values.remove(list_value)
+                self.window[self.event_key_js['-FILES_LIST-']].update(values=list_values)
+        self.window[self.event_key_js['-FILES_LIST-']].update(value=str(list_values))
     def return_directory(self):
         """
         Return the current directory or parent directory if a file path is provided.
